@@ -5,36 +5,14 @@
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
 #
-# Copyright 2002-2024 Univention GmbH
-#
-# https://www.univention.de/
-#
-# All rights reserved.
-#
-# The source code of this program is made available
-# under the terms of the GNU Affero General Public License version 3
-# (GNU AGPL V3) as published by the Free Software Foundation.
-#
-# Binary versions of this program provided by Univention to you as
-# well as other copyrighted, protected or trademarked materials like
-# Logos, graphics, fonts, specific documentations and configurations,
-# cryptographic keys etc. are subject to a license agreement between
-# you and Univention and not subject to the GNU AGPL V3.
-#
-# In the case you use this program under the terms of the GNU AGPL V3,
-# the program is provided in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Affero General Public License for more details.
-#
-# You should have received a copy of the GNU Affero General Public
-# License with the Debian GNU/Linux or Univention distribution in file
-# /usr/share/common-licenses/AGPL-3; if not, see
-# <https://www.gnu.org/licenses/>.
+# SPDX-FileCopyrightText: 2002-2025 Univention GmbH
+# SPDX-License-Identifier: AGPL-3.0-only
 
 import logging
 import random
 import re
+import traceback
+import warnings
 from collections.abc import Callable
 from functools import wraps
 from typing import Any
@@ -61,7 +39,7 @@ def parentDn(dn: str, base: str = '') -> str | None:
     :return: The parent distinguished name or None.
     :rtype: str or None
     """
-    if dn.lower() == base.lower():
+    if access.compare_dn(dn.lower(), base.lower()):
         return None
     dn = ldap.dn.str2dn(dn)
     return ldap.dn.dn2str(dn[1:])
@@ -264,6 +242,23 @@ class access:
         self.client_connection_attempt = client_retry_count + 1
 
         self.__open(ca_certfile)
+        if not self.base:
+            log.error('No LDAP base given to uldap.access()! Can lead to mysterious errors! %s', ''.join(traceback.format_stack()))
+            warnings.warn('No LDAP base given to uldap.access()! Can lead to mysterious errors!', DeprecationWarning, stacklevel=3)
+
+            # a empty base is valid in one scenario: when wanting to detect the base via a certain search.
+            # but this can set any random base and set it to empty afterwards
+            # note: search(base='') will fallback to self.base
+            if ucr.is_true('directory/mananger/type-checking/strict'):
+                raise TypeError('base must at least be set to LDAP base')
+
+    @property
+    def authz_connection(self):
+        log.error('Wrong access class in use! Use univention.admin.uldap instead of univention.uldap! %s', ''.join(traceback.format_stack()))
+        warnings.warn('Wrong access class in use! Use univention.admin.uldap instead of univention.uldap!', DeprecationWarning, stacklevel=3)
+        if ucr.is_true('directory/mananger/type-checking/strict'):
+            raise TypeError('univention.admin.uldap required!')
+        return self
 
     @_fix_reconnect_handling
     def bind(self, binddn: str, bindpw: str) -> None:
@@ -737,7 +732,7 @@ class access:
         new_rdn = ldap.dn.dn2str([new_rdn_unicode])
         rdn = ldap.dn.dn2str([rdn])
         if rdn != new_rdn:
-            return ldap.dn.dn2str([ldap.dn.str2dn(new_rdn)[0]] + ldap.dn.str2dn(dn)[1:]), new_rdn
+            return ldap.dn.dn2str([ldap.dn.str2dn(new_rdn)[0], *ldap.dn.str2dn(dn)[1:]]), new_rdn
         return dn, rdn
 
     @_fix_reconnect_handling
@@ -930,6 +925,8 @@ class access:
         >>> compare_dn(r'foo=\31', r'foo=1')
         True
         """
+        if a == b:
+            return True
         return [sorted((x.lower(), y, z) for x, y, z in rdn) for rdn in ldap.dn.str2dn(a)] == [sorted((x.lower(), y, z) for x, y, z in rdn) for rdn in ldap.dn.str2dn(b)]
 
     def __getstate__(self):
@@ -958,7 +955,7 @@ class access:
         if isLDAPUrl(ldap_url):
             conn_str = LDAPUrl(ldap_url).initializeUrl()
 
-            # FIXME?: this upgrades a access(reconnect=False) connection to a reconnect=True connection
+            # FIXME: ? this upgrades a access(reconnect=False) connection to a reconnect=True connection
             lo_ref = ldap.ldapobject.ReconnectLDAPObject(conn_str, trace_stack_limit=None)
 
             if self.ca_certfile:
