@@ -3,32 +3,8 @@
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
 #
-# Copyright 2022-2024 Univention GmbH
-#
-# https://www.univention.de/
-#
-# All rights reserved.
-#
-# The source code of this program is made available
-# under the terms of the GNU Affero General Public License version 3
-# (GNU AGPL V3) as published by the Free Software Foundation.
-#
-# Binary versions of this program provided by Univention to you as
-# well as other copyrighted, protected or trademarked materials like
-# Logos, graphics, fonts, specific documentations and configurations,
-# cryptographic keys etc. are subject to a license agreement between
-# you and Univention and not subject to the GNU AGPL V3.
-#
-# In the case you use this program under the terms of the GNU AGPL V3,
-# the program is provided in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Affero General Public License for more details.
-#
-# You should have received a copy of the GNU Affero General Public
-# License with the Debian GNU/Linux or Univention distribution in file
-# /usr/share/common-licenses/AGPL-3; if not, see
-# <https://www.gnu.org/licenses/>.
+# SPDX-FileCopyrightText: 2022-2025 Univention GmbH
+# SPDX-License-Identifier: AGPL-3.0-only
 
 import string
 
@@ -40,7 +16,7 @@ _uldap = import_module('uldap', 'modules/', 'univention.uldap', use_installed=Fa
 univention_password = import_module('password', 'modules/', 'univention.password', use_installed=False)
 
 
-@pytest.fixture()
+@pytest.fixture
 def mocked_ucr(mock_ucr, mocker):
     mock = mocker.patch.object(univention_password, 'ucr')
     mock.ucr = mock_ucr
@@ -342,7 +318,7 @@ class TestPasswordConfigExhaustedAvailableCharacterPool:
             univention_password.generate_password(**cfg)
 
     def test_exhausted_pool(self):
-        with pytest.raises(ValueError, match="All available characters are excluded by.*"):
+        with pytest.raises(ValueError, match=r"All available characters are excluded by.*"):
             cfg = {'digits': 1, 'lower': 1, 'other': 1, 'upper': 1, 'forbidden': string.printable, 'min_length': 6}
             univention_password.generate_password(**cfg)
 
